==> sirepo-bluesky-0.7.0.tar.gz: sirepo-bluesky-0.7.0/README.md <==
# Sirepo-Bluesky

[![Zenodo](https://zenodo.org/badge/243052461.svg)](https://zenodo.org/badge/latestdoi/243052461)
[![Test](https://github.com/NSLS-II/sirepo-bluesky/actions/workflows/testing.yml/badge.svg)](https://github.com/NSLS-II/sirepo-bluesky/actions/workflows/testing.yml)
[![PyPI](https://img.shields.io/pypi/v/sirepo-bluesky.svg?logo=pypi&logoColor=white&label=PyPI)](https://pypi.python.org/pypi/sirepo-bluesky)
[![Conda](https://img.shields.io/conda/vn/conda-forge/sirepo-bluesky.svg?logo=conda-forge&logoColor=white)](https://anaconda.org/conda-forge/sirepo-bluesky)

This is a Sirepo-Bluesky interface library that allows using the [Bluesky data
acquisition framework](https://blueskyproject.io) to run [Sirepo](https://github.com/radiasoft/sirepo) simulations (SRW, Shadow3, etc.)

* Free software: BSD-3-Clause license


## Documentation

Please check our documentation at https://nsls-ii.github.io/sirepo-bluesky for
installation instructions and examples using SRW, Shadow3, and MAD-X apps of
Sirepo.


## Citation

> M. Rakitin, A. Giles, K. Swartz, J. Lynch, P. Moeller, R. Nagler, D.B. Allan, T.A. Caswell, L. Wiegart, O. Chubar, and Y. Du _"Introduction of the Sirepo-Bluesky interface and its application to the optimization problems"_, Proc. SPIE 11493, Advances in Computational Methods for X-Ray Optics V, 1149311 (21 August 2020); https://doi.org/10.1117/12.2569000

BibTeX:
```
@InProceedings{2020.08-01:Rakitin,
  author       = {Rakitin, Maksim S. and Giles, Abigail and Swartz, Kaleb and Lynch, Joshua and Moeller, Paul and Nagler, Robert and Allan, Daniel B. and Caswell, Thomas A. and Wiegart, Lutz and Chubar, Oleg and Du, Yonghua},
  booktitle    = {Advances in Computational Methods for X-Ray Optics V},
  title        = {{Introduction of the Sirepo-Bluesky interface and its application to the optimization problems}},
  year         = {2020},
  editor       = {Oleg Chubar and Kawal Sawhney},
  month        = aug,
  organization = {International Society for Optics and Photonics},
  pages        = {209--226},
  publisher    = {SPIE},
  volume       = {11493},
  doi          = {10.1117/12.2569000},
  file         = {:papers/2020.08-01_Rakitin.pdf:PDF},
  keywords     = {Sirepo, SRW, Bluesky, Databroker, Ophyd, optimization, simulations},
  url          = {https://doi.org/10.1117/12.2569000},
}
```

==> sirepo-bluesky-0.7.1.tar.gz: sirepo-bluesky-0.7.1/README.md <==
# Sirepo-Bluesky

[![Zenodo](https://zenodo.org/badge/243052461.svg)](https://zenodo.org/badge/latestdoi/243052461)
[![Test](https://github.com/NSLS-II/sirepo-bluesky/actions/workflows/testing.yml/badge.svg)](https://github.com/NSLS-II/sirepo-bluesky/actions/workflows/testing.yml)
[![PyPI](https://img.shields.io/pypi/v/sirepo-bluesky.svg?logo=pypi&logoColor=white&label=PyPI)](https://pypi.python.org/pypi/sirepo-bluesky)
[![Conda](https://img.shields.io/conda/vn/conda-forge/sirepo-bluesky.svg?logo=conda-forge&logoColor=white)](https://anaconda.org/conda-forge/sirepo-bluesky)

This is a Sirepo-Bluesky interface library that allows using the [Bluesky data
acquisition framework](https://blueskyproject.io) to run [Sirepo](https://github.com/radiasoft/sirepo) simulations (SRW, Shadow3, etc.)

* Free software: BSD-3-Clause license


## Documentation

Please check our documentation at https://nsls-ii.github.io/sirepo-bluesky for
installation instructions and examples using SRW, Shadow3, and MAD-X apps of
Sirepo.


## Citation

> M. Rakitin, A. Giles, K. Swartz, J. Lynch, P. Moeller, R. Nagler, D.B. Allan, T.A. Caswell, L. Wiegart, O. Chubar, and Y. Du _"Introduction of the Sirepo-Bluesky interface and its application to the optimization problems"_, Proc. SPIE 11493, Advances in Computational Methods for X-Ray Optics V, 1149311 (21 August 2020); https://doi.org/10.1117/12.2569000

BibTeX:
```bibtex
@InProceedings{Sirepo-Bluesky:2020,
  author       = {Rakitin, Maksim S. and Giles, Abigail and Swartz, Kaleb and Lynch, Joshua and Moeller, Paul and Nagler, Robert and Allan, Daniel B. and Caswell, Thomas A. and Wiegart, Lutz and Chubar, Oleg and Du, Yonghua},
  booktitle    = {Advances in Computational Methods for X-Ray Optics V},
  title        = {{Introduction of the Sirepo-Bluesky interface and its application to the optimization problems}},
  year         = {2020},
  editor       = {Oleg Chubar and Kawal Sawhney},
  month        = aug,
  organization = {International Society for Optics and Photonics},
  pages        = {209--226},
  publisher    = {SPIE},
  volume       = {11493},
  doi          = {10.1117/12.2569000},
  keywords     = {Sirepo, SRW, Bluesky, Databroker, Ophyd, optimization, simulations},
  url          = {https://doi.org/10.1117/12.2569000},
}
```
